@@ -1,11 +1,11 @@
 #![no_std]
 
+pub mod error;
 pub mod group;
 pub mod peek;
-mod spin;
 pub mod state;
 
+pub use error::Error;
 pub use group::*;
 pub use peek::*;
-pub use spin::spin;
 pub use state::*;
